Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5029)

Unified Diff: chrome/browser/browser.h

Issue 67156: Fix regression I introduced where Stop/Go button would toggle state instantly... (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: Created 11 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/browser.cc » ('j') | chrome/browser/gtk/browser_window_gtk.cc » ('J')
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/browser.h
===================================================================
--- chrome/browser/browser.h (revision 13668)
+++ chrome/browser/browser.h (working copy)
@@ -488,9 +488,10 @@
// mode.
void UpdateCommandsForFullscreenMode(bool is_fullscreen);
- // Set the correct stop/go icon and update the Go and Stop command states.
- // |is_loading| is true if the current TabContents is loading.
- void UpdateStopGoState(bool is_loading);
+ // Ask the Stop/Go button to change its icon, and update the Go and Stop
+ // command states. |is_loading| is true if the current TabContents is
+ // loading. |force| is true if the button should change its icon immediately.
+ void UpdateStopGoState(bool is_loading, bool force);
// UI update coalescing and handling ////////////////////////////////////////
« no previous file with comments | « no previous file | chrome/browser/browser.cc » ('j') | chrome/browser/gtk/browser_window_gtk.cc » ('J')

Powered by Google App Engine
This is Rietveld 408576698